
# Type: gene to disease association_subject




URI: [biolink:gene_to_disease_association_subject](https://w3id.org/biolink/vocab/gene_to_disease_association_subject)


## Domain and Range

[GeneToDiseaseAssociation](GeneToDiseaseAssociation.md) ->  <sub>REQ</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [subject](subject.md)

## Children

 *  [gene as a model of disease association➞subject](gene_as_a_model_of_disease_association_subject.md)
 *  [gene has variant that contributes to disease association➞subject](gene_has_variant_that_contributes_to_disease_association_subject.md)

## Used by

 * [GeneToDiseaseAssociation](GeneToDiseaseAssociation.md)
